package com.staffing.custom.service;

import java.util.List;

import com.staffing.custom.domain.StEmployee;
import com.staffing.custom.domain.StTask;

/**
 * 任务Service接口
 * 
 * @author staffing
 * @date 2024-08-27
 */
public interface IStTaskService 
{
    /**
     * 查询任务
     * 
     * @param id 任务主键
     * @return 任务
     */
    public StTask selectStTaskById(Long id);

    /**
     * 查询任务
     * @param id
     * @param filterSign 过滤掉没签到的人员，再发薪页面调用的
     * @return
     */
    public StTask selectStTaskById(Long id, boolean filterSign);

    /**
     * 查询任务列表
     * 
     * @param stTask 任务
     * @return 任务集合
     */
    public List<StTask> selectStTaskList(StTask stTask, long uid);

    /**
     * 查询任务列表
     *
     * @param stTask 任务
     * @return 任务集合
     */
    public List<StTask> selectStTaskListByUserId(StTask stTask, Long userId, boolean sign);

    /**
     * 新增任务
     * 
     * @param stTask 任务
     * @return 结果
     */
    public int insertStTask(StTask stTask);

    /**
     * 修改任务
     * 
     * @param stTask 任务
     * @return 结果
     */
    public int updateStTask(StTask stTask);
    public int updateStTask(StTask stTask, boolean syncRelationsTabel);
    /**
     * 批量删除任务
     * 
     * @param ids 需要删除的任务主键集合
     * @return 结果
     */
    public int deleteStTaskByIds(Long[] ids);

    /**
     * 删除任务信息
     * 
     * @param id 任务主键
     * @return 结果
     */
    public int deleteStTaskById(Long id);

    void updateTaskUserInfo(StEmployee stEmployee);
}
